==> haskell-hsopenssl-0.11.7.9-93.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   HsOpenSSL
version:                0.11.7.9
visibility:             public
id:                     HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
key:                    HsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
license:                LicenseRef-PublicDomain
maintainer:             Vladimir Shabanov <dev@vshabanov.com>
author:                 Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability:              stable
homepage:               https://github.com/haskell-cryptography/HsOpenSSL
synopsis:               Partial OpenSSL binding for Haskell
description:
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.

    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.

category:               Cryptography
abi:                    37a637db75c2a23592789185acf576c4
exposed:                True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store

hidden-modules:
    OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR OpenSSL.Objects
    OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils OpenSSL.X509.Name
    OpenSSL.DH.Internal

import-dirs:            /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-hsopenssl
hs-libraries:           HSHsOpenSSL-0.11.7.9-96EVs0QSsusKamWieCsd7F
extra-libraries:        ssl crypto
extra-libraries-static: ssl crypto dl
include-dirs:           /usr/include
includes:               openssl/asn1.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe time-1.12.2

haddock-interfaces:     /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html:           /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-0.11.7.9-94-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   HsOpenSSL
version:                0.11.7.9
visibility:             public
id:                     HsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR
key:                    HsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR
license:                LicenseRef-PublicDomain
maintainer:             Vladimir Shabanov <dev@vshabanov.com>
author:                 Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability:              stable
homepage:               https://github.com/haskell-cryptography/HsOpenSSL
synopsis:               Partial OpenSSL binding for Haskell
description:
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.

    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.

category:               Cryptography
abi:                    80f5c82522819f6c2fb1fdbbf0e968f7
exposed:                True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store

hidden-modules:
    OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR OpenSSL.Objects
    OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils OpenSSL.X509.Name
    OpenSSL.DH.Internal

import-dirs:            /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/HsOpenSSL-0.11.7.9 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-hsopenssl
hs-libraries:           HSHsOpenSSL-0.11.7.9-7b2YaIo8nxa5WFX252B8AR
extra-libraries:        ssl crypto
extra-libraries-static: ssl crypto dl
include-dirs:           /usr/include
includes:               openssl/asn1.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ time-1.12.2

haddock-interfaces:     /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html:           /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
